pub fn block_announces_legacy_protocol_name(protocol_id: &ProtocolId) -> StringExpand description
Generate the legacy block announces protocol name from chain specific protocol identifier.
pub fn block_announces_legacy_protocol_name(protocol_id: &ProtocolId) -> StringGenerate the legacy block announces protocol name from chain specific protocol identifier.